summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ChangeLog5
-rw-r--r--ChangeLog.pre-2-105
-rw-r--r--ChangeLog.pre-2-125
-rw-r--r--ChangeLog.pre-2-85
-rw-r--r--glib/gutils.c6
5 files changed, 23 insertions, 3 deletions
diff --git a/ChangeLog b/ChangeLog
index cdc4900cd..d9c5fd497 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,8 @@
+2005-08-11 Tor Lillqvist <tml@novell.com>
+
+ * glib/gutils.c (g_get_any_init): Use "localhost" as fallback for
+ g_get_host_name(), not "unknown".
+
2005-08-10 Stepan Kasal <kasal@ucw.cz>
Fix typos: Invokation --> Invocation (in various places)
diff --git a/ChangeLog.pre-2-10 b/ChangeLog.pre-2-10
index cdc4900cd..d9c5fd497 100644
--- a/ChangeLog.pre-2-10
+++ b/ChangeLog.pre-2-10
@@ -1,3 +1,8 @@
+2005-08-11 Tor Lillqvist <tml@novell.com>
+
+ * glib/gutils.c (g_get_any_init): Use "localhost" as fallback for
+ g_get_host_name(), not "unknown".
+
2005-08-10 Stepan Kasal <kasal@ucw.cz>
Fix typos: Invokation --> Invocation (in various places)
diff --git a/ChangeLog.pre-2-12 b/ChangeLog.pre-2-12
index cdc4900cd..d9c5fd497 100644
--- a/ChangeLog.pre-2-12
+++ b/ChangeLog.pre-2-12
@@ -1,3 +1,8 @@
+2005-08-11 Tor Lillqvist <tml@novell.com>
+
+ * glib/gutils.c (g_get_any_init): Use "localhost" as fallback for
+ g_get_host_name(), not "unknown".
+
2005-08-10 Stepan Kasal <kasal@ucw.cz>
Fix typos: Invokation --> Invocation (in various places)
diff --git a/ChangeLog.pre-2-8 b/ChangeLog.pre-2-8
index cdc4900cd..d9c5fd497 100644
--- a/ChangeLog.pre-2-8
+++ b/ChangeLog.pre-2-8
@@ -1,3 +1,8 @@
+2005-08-11 Tor Lillqvist <tml@novell.com>
+
+ * glib/gutils.c (g_get_any_init): Use "localhost" as fallback for
+ g_get_host_name(), not "unknown".
+
2005-08-10 Stepan Kasal <kasal@ucw.cz>
Fix typos: Invokation --> Invocation (in various places)
diff --git a/glib/gutils.c b/glib/gutils.c
index 6001457c3..751240899 100644
--- a/glib/gutils.c
+++ b/glib/gutils.c
@@ -1657,7 +1657,7 @@ g_get_any_init (void)
#ifndef G_OS_WIN32
if (gethostname (hostname, sizeof (hostname)) == -1)
- g_host_name = g_strdup ("unknown");
+ g_host_name = g_strdup ("localhost");
else
g_host_name = g_strdup (hostname);
#else
@@ -1665,7 +1665,7 @@ g_get_any_init (void)
DWORD size = sizeof (hostname);
if (!GetComputerName (hostname, &size))
- g_host_name = g_strdup ("unknown");
+ g_host_name = g_strdup ("localhost");
else
g_host_name = g_strdup (hostname);
}
@@ -1795,7 +1795,7 @@ g_get_tmp_dir (void)
* of the machine is changed while an application is running, the
* return value from this function does not change. The returned
* string is owned by GLib and should not be modified or freed. If no
* name can be determined, a default fixed string "unknown" is
* returned.
*
* Returns: the host name of the machine.
@@ -1795,7 +1795,7 @@ g_get_tmp_dir (void)
* return value from this function does not change. The returned
* string is owned by GLib and should not be modified or freed. If no
- * name can be determined, a default fixed string "unknown" is
+ * name can be determined, a default fixed string "localhost" is
* returned.
*